package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.SysSourceDefault;
//import io.lettuce.core.dynamic.annotation.Param;
import org.apache.ibatis.annotations.Param;
/**
 * 资源位默认配置Mapper接口
 * 
 * @author haotian
 * @date 2025-04-21
 */
public interface SysSourceDefaultMapper 
{
    /**
     * 查询资源位默认配置
     * 
     * @param id 资源位默认配置主键
     * @return 资源位默认配置
     */
    public SysSourceDefault selectSysSourceDefaultById(Long id);

    /**
     * 查询资源位默认配置列表
     * 
     * @param sysSourceDefault 资源位默认配置
     * @return 资源位默认配置集合
     */
    public List<SysSourceDefault> selectSysSourceDefaultList(SysSourceDefault sysSourceDefault);

    /**
     * 新增资源位默认配置
     * 
     * @param sysSourceDefault 资源位默认配置
     * @return 结果
     */
    public int insertSysSourceDefault(SysSourceDefault sysSourceDefault);

    /**
     * 修改资源位默认配置
     * 
     * @param sysSourceDefault 资源位默认配置
     * @return 结果
     */
    public int updateSysSourceDefault(SysSourceDefault sysSourceDefault);

    /**
     * 删除资源位默认配置
     * 
     * @param id 资源位默认配置主键
     * @return 结果
     */
    public int deleteSysSourceDefaultById(Long id);

    /**
     * 批量删除资源位默认配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysSourceDefaultByIds(Long[] ids);

    /**
     *
     * 根据资源位id修改默认背景图片@Param("city")
     * */
    public int updateSysSourceDefaultWorkBySourceId(@Param("sourceId") Long sourceId, @Param("workAddress") String workAddress);

    /**
     *更新默认价格
     */
    public int updateDefaultSourcePrice(@Param("scenicId") Long scenicId,@Param("part") String part, @Param("price") String price);

    /**
     * 根据sourceId返回SysSourceDefault
     * */
    public SysSourceDefault getSourceDefaultBySourceId(@Param("sourceId") Long sourceId);


}
