//package com.ruoyi.system.controller;
//
//import java.util.List;
//import javax.servlet.http.HttpServletResponse;
//import org.springframework.security.access.prepost.PreAuthorize;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.web.bind.annotation.GetMapping;
//import org.springframework.web.bind.annotation.PostMapping;
//import org.springframework.web.bind.annotation.PutMapping;
//import org.springframework.web.bind.annotation.DeleteMapping;
//import org.springframework.web.bind.annotation.PathVariable;
//import org.springframework.web.bind.annotation.RequestBody;
//import org.springframework.web.bind.annotation.RequestMapping;
//import org.springframework.web.bind.annotation.RestController;
//import com.ruoyi.common.annotation.Log;
//import com.ruoyi.common.core.controller.BaseController;
//import com.ruoyi.common.core.domain.AjaxResult;
//import com.ruoyi.common.enums.BusinessType;
//import com.ruoyi.system.domain.SysSourceDefault;
//import com.ruoyi.system.service.ISysSourceDefaultService;
//import com.ruoyi.common.utils.poi.ExcelUtil;
//import com.ruoyi.common.core.page.TableDataInfo;
//
///**
// * 资源位默认配置Controller
// *
// * @author haotian
// * @date 2025-04-21
// */
//@RestController
//@RequestMapping("/system/default")
//public class SysSourceDefaultController extends BaseController
//{
//    @Autowired
//    private ISysSourceDefaultService sysSourceDefaultService;
//
//    /**
//     * 查询资源位默认配置列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:default:list')")
//    @GetMapping("/list")
//    public TableDataInfo list(SysSourceDefault sysSourceDefault)
//    {
//        startPage();
//        List<SysSourceDefault> list = sysSourceDefaultService.selectSysSourceDefaultList(sysSourceDefault);
//        return getDataTable(list);
//    }
//
//    /**
//     * 导出资源位默认配置列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:default:export')")
//    @Log(title = "资源位默认配置", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, SysSourceDefault sysSourceDefault)
//    {
//        List<SysSourceDefault> list = sysSourceDefaultService.selectSysSourceDefaultList(sysSourceDefault);
//        ExcelUtil<SysSourceDefault> util = new ExcelUtil<SysSourceDefault>(SysSourceDefault.class);
//        util.exportExcel(response, list, "资源位默认配置数据");
//    }
//
//    /**
//     * 获取资源位默认配置详细信息
//     */
//    @PreAuthorize("@ss.hasPermi('system:default:query')")
//    @GetMapping(value = "/{id}")
//    public AjaxResult getInfo(@PathVariable("id") Long id)
//    {
//        return success(sysSourceDefaultService.selectSysSourceDefaultById(id));
//    }
//
//    /**
//     * 新增资源位默认配置
//     */
//    @PreAuthorize("@ss.hasPermi('system:default:add')")
//    @Log(title = "资源位默认配置", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody SysSourceDefault sysSourceDefault)
//    {
//        return toAjax(sysSourceDefaultService.insertSysSourceDefault(sysSourceDefault));
//    }
//
//    /**
//     * 修改资源位默认配置
//     */
//    @PreAuthorize("@ss.hasPermi('system:default:edit')")
//    @Log(title = "资源位默认配置", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody SysSourceDefault sysSourceDefault)
//    {
//        return toAjax(sysSourceDefaultService.updateSysSourceDefault(sysSourceDefault));
//    }
//
//    /**
//     * 删除资源位默认配置
//     */
//    @PreAuthorize("@ss.hasPermi('system:default:remove')")
//    @Log(title = "资源位默认配置", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{ids}")
//    public AjaxResult remove(@PathVariable Long[] ids)
//    {
//        return toAjax(sysSourceDefaultService.deleteSysSourceDefaultByIds(ids));
//    }
//}
